@@ -1,7 +1,6 @@
 package Langertha::Engine::vLLM;
-our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: vLLM inference server
-$Langertha::Engine::vLLM::VERSION = '0.008';
+our $VERSION = '0.100';
 use Moose;
 use Carp qw( croak );
 
@@ -34,7 +33,7 @@ Langertha::Engine::vLLM - vLLM inference server
 
 =head1 VERSION
 
-version 0.008
+version 0.100
 
 =head1 SYNOPSIS
 
@@ -56,19 +55,16 @@ B<THIS API IS WORK IN PROGRESS>
 
 L<https://docs.vllm.ai/en/latest/getting_started/installation.html>
 
-=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
-
 =head1 SUPPORT
 
-=head2 Source Code
+=head2 Issues
 
-The code is open to the world, and available for you to hack on. Please feel free to browse it and play
-with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
-from your repository :)
+Please report bugs and feature requests on GitHub at
+L<https://github.com/Getty/langertha/issues>.
 
-L<https://github.com/Getty/langertha>
+=head1 CONTRIBUTING
 
-  git clone https://github.com/Getty/langertha.git
+Contributions are welcome! Please fork the repository and submit a pull request.
 
 =head1 AUTHOR
 
@@ -76,7 +72,7 @@ Torsten Raudssus <torsten@raudssus.de> L<https://raudss.us/>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2024 by Torsten Raudssus.
+This software is copyright (c) 2026 by Torsten Raudssus.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
