@@ -1,7 +1,6 @@
 package Langertha::Role::Models;
-our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Role for APIs with several models
-$Langertha::Role::Models::VERSION = '0.008';
+our $VERSION = '0.100';
 use Moose::Role;
 
 requires qw(
@@ -15,6 +14,8 @@ has models => (
 );
 sub _build_models {
   my ( $self ) = @_;
+  # Prefer dynamic list_models() over static all_models()
+  return $self->list_models() if $self->can('list_models');
   return [
     $self->can('all_models')
       ? $self->all_models
@@ -32,6 +33,30 @@ sub _build_model {
   return $self->default_model;
 }
 
+# Cache configuration
+has models_cache_ttl => (
+  is => 'ro',
+  isa => 'Int',
+  default => sub { 3600 }, # 1 hour default
+);
+
+has _models_cache => (
+  is => 'rw',
+  isa => 'HashRef',
+  default => sub { {} },
+  traits => ['Hash'],
+  handles => {
+    _clear_models_cache => 'clear',
+  },
+);
+
+# Public method to clear the cache
+sub clear_models_cache {
+  my ($self) = @_;
+  $self->_clear_models_cache;
+  return;
+}
+
 1;
 
 __END__
@@ -46,21 +71,18 @@ Langertha::Role::Models - Role for APIs with several models
 
 =head1 VERSION
 
-version 0.008
-
-=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+version 0.100
 
 =head1 SUPPORT
 
-=head2 Source Code
+=head2 Issues
 
-The code is open to the world, and available for you to hack on. Please feel free to browse it and play
-with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
-from your repository :)
+Please report bugs and feature requests on GitHub at
+L<https://github.com/Getty/langertha/issues>.
 
-L<https://github.com/Getty/langertha>
+=head1 CONTRIBUTING
 
-  git clone https://github.com/Getty/langertha.git
+Contributions are welcome! Please fork the repository and submit a pull request.
 
 =head1 AUTHOR
 
@@ -68,7 +90,7 @@ Torsten Raudssus <torsten@raudssus.de> L<https://raudss.us/>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2024 by Torsten Raudssus.
+This software is copyright (c) 2026 by Torsten Raudssus.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
